from fastapi import APIRouter, Depends

from app.api.deps import get_current_active_superuser
from app.api.routes import chat, collections, documents, groups, login, users, utils
from app.core.config import settings
from app.core.tus import create_api_router

api_router = APIRouter()
api_router.include_router(login.router, tags=["login"])
api_router.include_router(
    groups.router,
    prefix="/groups",
    tags=["groups"],
    dependencies=[Depends(get_current_active_superuser)],
)
api_router.include_router(users.router, prefix="/users", tags=["users"])
api_router.include_router(utils.router, prefix="/utils", tags=["utils"])
api_router.include_router(collections.router, prefix="/collections", tags=["collections"])
api_router.include_router(documents.router, prefix="/documents", tags=["documents"])
api_router.include_router(chat.router, prefix="/chat", tags=["chat"])


file_router: APIRouter = create_api_router(
    files_dir="/tmp/files",
    max_size=settings.MAX_UPLOAD_SIZE_IN_MB * 1024 * 1024,
    on_upload_complete=collections.on_tus_upload_complete,
    days_to_keep=2,
    prefix="files",
    tags=["files"],
)

api_router.include_router(file_router)
