import logging
from typing import Any

from posthog import Posthog

from app.core.config import settings

logger = logging.getLogger("uvicorn.error")

__all__ = ["telemetry_client"]


class TelemetryClient:
    def __init__(self, api_key: str | None = None) -> None:
        self.is_enabled = isinstance(api_key, str)
        if isinstance(api_key, str):
            self.ph_client = Posthog(project_api_key=api_key, host="https://eu.posthog.com")
            logger.info("PostHog enabled")

    def capture(self, *args: Any, **kwargs: Any) -> None:
        if self.is_enabled:
            self.ph_client.capture(*args, **kwargs)

    def identify(self, *args: Any, **kwargs: Any) -> None:
        if self.is_enabled:
            self.ph_client.identify(*args, **kwargs)

    def alias(self, *args: Any, **kwargs: Any) -> None:
        if self.is_enabled:
            self.ph_client.alias(*args, **kwargs)


telemetry_client = TelemetryClient(api_key=settings.POSTHOG_KEY)
