from fastapi.testclient import TestClient
from sqlmodel import Session

from app.core.config import settings
from app.models import UserRole
from app.tests.utils.user import random_authenticated_user
from app.tests.utils.utils import random_lower_string


def test_create_group(client: TestClient, superuser_token_headers: dict[str, str]) -> None:
    data = {"name": "Test", "domain": "test.com"}
    response = client.post(f"{settings.API_V1_STR}/groups/", headers=superuser_token_headers, json=data)
    assert response.status_code == 200, response.text
    content = response.json()
    assert content["name"] == data["name"]
    assert content["domain"] == data["domain"]
    assert "id" in content


def test_create_group_permission(client: TestClient, test_db: Session, superuser_token_headers: dict[str, str]) -> None:
    data = {}

    group_admin = random_authenticated_user(test_db, role=UserRole.groupadmin, group_id=1)
    group_contributor = random_authenticated_user(test_db, role=UserRole.contributor, group_id=1)
    group_member = random_authenticated_user(test_db, role=UserRole.user, group_id=1)

    for token, expected_status in [
        (superuser_token_headers, 200),
        (group_admin.token, 403),
        (group_contributor.token, 403),
        (group_member.token, 403),
    ]:
        data["name"] = random_lower_string()
        response = client.post(f"{settings.API_V1_STR}/groups/", headers=token, json=data)
        assert response.status_code == expected_status
