import uuid

from sqlalchemy.engine import Engine
from sqlmodel import Session, text

from app.tests.migrations.conftest import create_collection, create_group, create_user, load_migration_as_module

# Load migration as module
migration = load_migration_as_module("2f61ad989231_add_chat_history.py")
rev_base = migration.down_revision
rev_head: str = migration.revision


def on_init(engine: Engine) -> None:
    """
    Create rows in users table before migration is applied
    """
    chat_id = uuid.uuid4()
    with Session(engine) as session:
        group_id = create_group(session)
        user_id = create_user(session, group_id)
        collection_id = create_collection(session, group_id, user_id)
        query = text(f"""insert into public.chatquery(id, collection_id, user_id, query, created_at)
        values('{chat_id}', '{collection_id}', '{user_id}', 'test', current_timestamp);""")
        session.execute(query)
        session.commit()


def on_upgrade(engine: Engine) -> None:
    """
    Ensure that data was successfully migrated
    """
    with Session(engine) as session:
        query = text("select * from public.chatquery")
        res = session.execute(query).first()
        assert hasattr(res, "updated_at")
        assert res and res.created_at == res.updated_at
        assert res.title == res.query
        assert res.history == []


def on_downgrade(engine: Engine) -> None:
    """
    Ensure that data changes were rolled back
    """
    with Session(engine) as session:
        query = text("select * from public.chatquery")
        res = session.execute(query).first()
        assert res and not hasattr(res, "updated_at") and hasattr(res, "id")
        assert not hasattr(res, "title")
        assert not hasattr(res, "history")
