import uuid
from datetime import datetime

from sqlalchemy.engine import Engine
from sqlmodel import Session, text

from app.tests.migrations.conftest import create_collection, create_group, create_user, load_migration_as_module

# Load migration as module
migration = load_migration_as_module("b6e2cf2d4ee5_add_timestamp_to_chat_query.py")
rev_base = migration.down_revision
rev_head: str = migration.revision


def on_init(engine: Engine) -> None:
    """
    Create rows in users table before migration is applied
    """
    chat_id = uuid.uuid4()
    with Session(engine) as session:
        group_id = create_group(session)
        user_id = create_user(session, group_id)
        collection_id = create_collection(session, group_id, user_id)
        query = text(f"""insert into public.chatquery(id, collection_id, user_id, query)
        values('{chat_id}', '{collection_id}', '{user_id}', 'test');""")
        session.execute(query)
        session.commit()


def on_upgrade(engine: Engine) -> None:
    """
    Ensure that data was successfully migrated
    """
    original_date = datetime.strptime("2025-01-29", "%Y-%m-%d")
    with Session(engine) as session:
        query = text("select * from public.chatquery")
        res = session.execute(query).first()
        assert hasattr(res, "created_at")
        assert res and res.created_at == original_date


def on_downgrade(engine: Engine) -> None:
    """
    Ensure that data changes were rolled back
    """
    with Session(engine) as session:
        query = text("select * from public.chatquery")
        res = session.execute(query).first()
        assert res and not hasattr(res, "created_at") and hasattr(res, "id")
