import uuid

from sqlalchemy.engine import Engine
from sqlmodel import Session, text

from app.tests.migrations.conftest import create_collection, create_group, create_user, load_migration_as_module

# Load migration as module
migration = load_migration_as_module("bb5b4cdab369_processing_status_is_failure.py")

rev_base = migration.down_revision
rev_head: str = migration.revision

document_id = uuid.uuid4()


def on_init(engine: Engine) -> None:
    """
    Create rows in users table before migration is applied
    """
    global document_id

    document_id = uuid.uuid4()
    with Session(engine) as session:
        group_id = create_group(session)
        user_id = create_user(session, group_id)
        collection_id = create_collection(session, group_id, user_id)
        query = text(f"""insert into public.document(id, filename, content_length, collection_id, created_at, updated_at, processing_status)
        values('{document_id}', 'test.pdf', 1000, '{collection_id}', current_timestamp, current_timestamp, 'failed');""")
        session.execute(query)
        session.commit()


def on_upgrade(engine: Engine) -> None:
    """
    Ensure that data was successfully migrated
    """
    global document_id

    with Session(engine) as session:
        query = text(f"select * from public.document where id='{document_id}'")
        res = session.execute(query).first()
        assert res and res.processing_status == "failure"


def on_downgrade(engine: Engine) -> None:
    """
    Ensure that data changes were rolled back
    """
    global document_id

    with Session(engine) as session:
        query = text(f"select * from public.document where id='{document_id}'")
        res = session.execute(query).first()
        assert res and res.processing_status == "failed"
