"""
Check data is migrated correctly in "data" migrations.
See data_migrations/migration_*.py for example.
"""

from collections.abc import Callable

import pytest
from alembic.command import downgrade, upgrade
from alembic.config import Config
from sqlalchemy import Engine, create_engine

from app.tests.migrations.conftest import MigrationValidationParamsGroup, make_validation_params_groups
from app.tests.migrations.data_migrations import (
    migration_2f61ad989231,
    migration_11d362313208,
    migration_b6e2cf2d4ee5,
    migration_bb5b4cdab369,
)


def get_data_migrations() -> list[MigrationValidationParamsGroup]:
    """
    Returns tests for data migrations, from tests/data_migrations folder.
    """
    return make_validation_params_groups(
        migration_11d362313208, migration_b6e2cf2d4ee5, migration_bb5b4cdab369, migration_2f61ad989231
    )


@pytest.mark.parametrize(("rev_base", "rev_head", "on_init", "on_upgrade", "on_downgrade"), get_data_migrations())
def test_data_migrations(
    alembic_config: Config,
    migration_postgres: str,
    rev_base: str,
    rev_head: str,
    on_init: Callable[[Engine], None],
    on_upgrade: Callable[[Engine], None],
    on_downgrade: Callable[[Engine], None],
) -> None:
    engine = create_engine(migration_postgres)

    upgrade(alembic_config, rev_base)
    on_init(engine)

    # # Perform upgrade in tested migration.
    # # Check that data is migrated correctly in on_upgrade callback
    upgrade(alembic_config, rev_head)
    on_upgrade(engine)

    # # Perform downgrade in tested migration.
    # # Check that changes are reverted back using on_downgrade callback
    downgrade(alembic_config, rev_base)
    on_downgrade(engine)
