"""
Test can find forgotten downgrade methods, undeleted data types in downgrade
methods, typos and many other errors.

Does not require any maintenance - you just add it once to check 80% of typos
and mistakes in migrations forever.

Inspired from : https://github.com/alvassin/alembic-quickstart/blob/da25b4964b481891cd6765797f7c08b75f5cea87/tests/migrations/test_stairway.py
"""

import pytest
from alembic.command import downgrade, upgrade
from alembic.config import Config
from alembic.script import Script, ScriptDirectory

from .conftest import make_alembic_config


def get_revisions() -> list[Script]:
    # Create Alembic configuration object
    # (we don't need database for getting revisions list)
    config = make_alembic_config()

    # Get directory object with Alembic migrations
    revisions_dir = ScriptDirectory.from_config(config)

    # Get & sort migrations, from first to last
    revisions = list(revisions_dir.walk_revisions("base", "heads"))
    revisions.reverse()
    return revisions


@pytest.mark.parametrize("revision", get_revisions())
def test_migrations_stairway(alembic_config: Config, revision: Script) -> None:
    upgrade(alembic_config, revision.revision)

    # We need -1 for downgrading first migration (its down_revision is None)
    rev = str(revision.down_revision) if revision.down_revision else "-1"
    downgrade(alembic_config, rev)
    upgrade(alembic_config, revision.revision)
