from collections.abc import Generator
from enum import Enum

from sqlmodel import Session

from app.models import UserRole
from app.tests.utils.user import AuthenticatedUser, random_authenticated_user

UserPerm = Enum("UserPerm", "none superadmin creator group_admin group_contributor group_member other_group_admin")


def user_generator(
    test_db: Session, collection_creator: AuthenticatedUser, exp_usr_status: dict[UserPerm, int]
) -> Generator[tuple[dict[str, str], int], None, None]:
    super_admin = random_authenticated_user(test_db, role=UserRole.superadmin, group_id=1)
    group_admin = random_authenticated_user(test_db, role=UserRole.groupadmin, group_id=1)
    group_contributor = random_authenticated_user(test_db, role=UserRole.contributor, group_id=1)
    group_member = random_authenticated_user(test_db, role=UserRole.user, group_id=1)
    group_admin_2 = random_authenticated_user(test_db, role=UserRole.groupadmin, group_id=2)
    yield from [
        ({"": ""}, exp_usr_status[UserPerm.none]),
        (super_admin.token, exp_usr_status[UserPerm.superadmin]),
        (collection_creator.token, exp_usr_status[UserPerm.creator]),
        (group_contributor.token, exp_usr_status[UserPerm.group_contributor]),
        (group_member.token, exp_usr_status[UserPerm.group_member]),
        (group_admin_2.token, exp_usr_status[UserPerm.other_group_admin]),
    ]
    # group_admin is often the creator
    if UserPerm.group_admin in exp_usr_status:
        yield (group_admin.token, exp_usr_status[UserPerm.group_admin])
