import random
import string

from fastapi.testclient import TestClient
from sqlmodel import Session

from app import crud
from app.core.config import settings
from app.models import User, UserCreate, UserRole


def random_lower_string() -> str:
    return "".join(random.choices(string.ascii_lowercase, k=32))


def random_email() -> str:
    return f"{random_lower_string()}@{random_lower_string()}.com"


def create_random_user(
    session: Session, role: UserRole | None = None, disabled: bool = False, email: str | None = None
) -> User:
    email = random_email() if email is None else email
    password = random_lower_string()
    role = UserRole.user if role is None else role
    user_in = UserCreate(email=email, password=password, group_id=1, role=role, disabled=disabled)
    user = crud.create_user(session=session, user_create=user_in)
    return user


def get_superuser_token_headers(client: TestClient) -> dict[str, str]:
    login_data = {
        "username": settings.FIRST_SUPERUSER,
        "password": settings.FIRST_SUPERUSER_PASSWORD,
    }
    r = client.post(f"{settings.API_V1_STR}/login/access-token", data=login_data)
    tokens = r.json()
    assert r.status_code == 200, r.text
    a_token = tokens["access_token"]
    headers = {"Authorization": f"Bearer {a_token}"}
    return headers
